#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-8dXJHMHsAt1EbIWBeN8y9V
key:                  string-conversions-0.4.0.1-8dXJHMHsAt1EbIWBeN8y9V
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  2ee9c71123f162a1537f30e84e7aa75a
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-8dXJHMHsAt1EbIWBeN8y9V
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

